require_relative 'spec_helper'

describe 'openstack-dns::common' do
  ALL_RHEL.each do |p|
    context "redhat #{p[:version]}" do
      let(:runner) { ChefSpec::SoloRunner.new(p) }
      let(:node) { runner.node }
      cached(:chef_run) do
        runner.converge(described_recipe)
      end

      include_context 'dns-stubs'

      it 'converges successfully' do
        expect { :chef_run }.to_not raise_error
      end
      it do
        expect(chef_run).to_not include_recipe('openstack-common::logging')
      end
      it 'install designate packages' do
        expect(chef_run).to upgrade_package %w(openstack-designate-api openstack-designate-central openstack-designate-mdns openstack-designate-producer openstack-designate-worker openstack-designate-sink)
      end

      case p
      when REDHAT_7
        it do
          expect(chef_run).to upgrade_package('MySQL-python')
        end
      when REDHAT_8
        it do
          expect(chef_run).to upgrade_package('python3-PyMySQL')
        end
      end
      it do
        expect(chef_run).to create_template('/etc/designate/pools.yaml').with(
          source: 'pools.yaml.erb',
          owner: 'designate',
          group: 'designate',
          mode: '644',
          variables: {
            banner: "\n# This file was autogenerated by Chef\n# Do not edit, changes will be overwritten\n",
            bind_hosts: %w(127.0.0.1),
            masters: %w(127.0.0.1),
            ns_addresses: %w(127.0.0.1),
            ns_hostnames: %w(ns1.example.org.),
            rndc_key: '/etc/designate/rndc.key',
          }
        )
      end
    end
  end
end
